% Experimental data from literature - figure 2
% Salil Apte 
% 23.03.2017
clear all
clc

addpath(genpath('superbar-master'))
bws = -5:5:80;
r1 = [228 26 28]./255;
b1 = [55 126 184]./255;
g1 = [77 175 74]./255;
l1 = [152 78 163]./255;
Colour = [r1;b1;g1;l1];
%% Hip Joint Kinematics
%treadmill, healthy
HK1 = [NaN, 42.9/42.9, 42.55/42.9, 42.2/42.9, 41.7750/42.9,  41.35/42.9,   40.925/42.9,  40.5/42.9,  39.6/42.9,  38.7/42.9, 37.8/42.9,  36.9/42.9,  35.4/42.9, 33.9/42.9,  32.4/42.9, 30.9/42.9, NaN, NaN; %Threlkeld 2003
       NaN, 16.513/16.513 , NaN, NaN, NaN, NaN, 14.3795/16.513, NaN,  NaN,  NaN, NaN,  11.4763/16.513 ,  NaN, NaN,  NaN,  NaN, 8.1973/16.513 , NaN ; %Van Hedel 2006  2km/h
       NaN, 41.2/41.2, NaN, NaN, NaN,  36.5/41.2,   NaN,  NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN] ; %Franz 2007   
        
HK1L = HK1(:,2:17);
bws1 = repmat(bws(2:17),3,1);
HK1_lm = fitlm(bws1(:),HK1L(:));

HK1 = [fillmissing(HK1(1,:),'linear','Endvalues','none');
        fillmissing(HK1(2,:),'linear','Endvalues','none');
        fillmissing(HK1(3,:),'linear','Endvalues','none')];

%overground, healthy
HK2 = [ 47.60/46.55, 46.55/46.55, 45.7850/46.55, 45.02/46.55, 44.8050/46.55,  44.59/46.55,   42.72/46.55,  40.85/46.55,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN ; %Patino 2007
        43.7/36.4, 36.4/36.4, 35.475/36.4, 34.55/36.4, 32.7/36.4,  30.8/36.4,   28.9/36.4,  27/36.4,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN ; %Fischer 2014
        NaN, 34.47/34.47, 33.87/34.47, 33.27/34.47, 31.775/34.47,  30.28/34.47,   29.13/34.47,  27.98/34.47,  27.48/34.47,  26.98/34.47, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; %Mun 2016

HK2L = HK2(:,2:10);
bws2 = repmat(bws(2:10),3,1);
HK2_lm = fitlm(bws2(:),HK2L(:));

HK2 = [fillmissing(HK2(1,:),'linear','Endvalues','none');
        fillmissing(HK2(2,:),'linear','Endvalues','none');
        fillmissing(HK2(3,:),'linear','Endvalues','none')];

%overground, NI - nonparetic
HK3 = [34.27/32.73, 32.73/32.73, 32.18/32.73, 31.63/32.73, 31.08/32.73,  30.53/32.73,   29.98/32.73,  29.43/32.73,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN] ; %Sousa 2009 NonParetic
HK3_lm = fitlm(bws(2:8),HK3(2:8));
HK3 = [fillmissing(HK3(1,:),'linear','Endvalues','none')];
%overground, NI - paretic
HK4 = [19.72/18.21, 18.21/18.21, 18.1283/18.21, 18.0466/18.21, 17.9649/18.21,  17.8832/18.21,   17.8015/18.21,  17.72/18.21, NaN, NaN, NaN, NaN,  NaN, NaN ,NaN,  NaN , NaN, NaN]; %Sousa 2009 Paretic
HK4_lm = fitlm(bws(2:8),HK4(2:8));
HK4 = [fillmissing(HK4(1,:),'linear','Endvalues','none')];

HK1M = mean(HK1,'omitnan');
HK1S = std(HK1,'omitnan');
HK2M = mean(HK2,'omitnan');
HK2S = std(HK2,'omitnan');
HK3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HK4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HKM = [HK1M;HK2M;HK3;HK4]';
HKS = [HK1S;HK2S;HK3S;HK4S]';

figure 
superbar(bws,HKM, 'E', HKS,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 1.5])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Hip angle - ROM','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
HK1M_est = -0.0047.*bws(2:17) + 1.0;
plot(bws(2:17),HK1M_est,'r--','linewidth',2) 
HK2M_est = -0.0061.*bws(2:10) + 1.0109;
plot(bws(2:10),HK2M_est,'b--','linewidth',2)
HK3_est = -0.0034.*bws(2:8) + 1;
plot(bws(2:8),HK3_est,'g--','linewidth',2)
HK4_est = -0.000897073821291271.*bws(2:8) + 1;
plot(bws(2:8),HK4_est,'m--','linewidth',2)

%% Knee joint kinematics

%bws =  -5     0     5    10    15    20    25    30    35    40    45    50   55    60    65    70
%treadmill, healthy
KK1 = [  NaN, 63.2/63.2, NaN, 63.7/63.2, NaN,  NaN,   NaN,  59.4/63.2,  NaN,  NaN, NaN,  57.2/63.2,  NaN, NaN,  NaN, 52.5/63.2, NaN, NaN; %Threlkeld 2003 
        NaN, 50.6403/50.6403 , NaN, NaN, NaN, NaN, 50.8988/50.6403, NaN,  NaN,  NaN, NaN,  47.3259/50.6403 ,  NaN, NaN,  NaN,  NaN, 45.4132/50.6403 , NaN ] ; %Van Hedel 2006  2km/h

KK1L = KK1(:,2:17);
bws1 = repmat(bws(2:17),2,1);
KK1_lm = fitlm(bws1(:),KK1L(:));

KK1 = [fillmissing(KK1(1,:),'linear','Endvalues','none');
        fillmissing(KK1(2,:),'linear','Endvalues','none')];

%overground, healthy
KK2 = [ 59.97/60.24, 60.24/60.24, NaN, 60.15/60.24, NaN,  57.79/60.24,   NaN,  51.75/60.24,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN; %Patino 2007
        58.9/54.3, 54.3/54.3, NaN, NaN, 53.9/54.3,  NaN,   NaN,  49.7/54.3,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN; %Fischer 2014
        NaN, 52.38/52.38, NaN, 49.98/52.38, NaN, 48.06/52.38,   NaN,  47.80/52.38,  NaN,  46.33/52.38, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; %Mun 2016

KK2L = KK2(:,2:10);
bws2 = repmat(bws(2:10),3,1);
KK2_lm = fitlm(bws2(:),KK2L(:));

KK2 = [fillmissing(KK2(1,:),'linear','Endvalues','none');
        fillmissing(KK2(2,:),'linear','Endvalues','none');  
        fillmissing(KK2(3,:),'linear','Endvalues','none')];

%overground, NI - nonparetic
KK3 = [51.76/49.32, 49.32/49.32, NaN, NaN, NaN,  NaN,   NaN,  47.38/49.32,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN]; %Sousa 2009 NonParetic
KK3_lm = fitlm(bws(2:8),KK3(2:8));
KK3 = [fillmissing(KK3(1,:),'linear','Endvalues','none')];
%overground, NI - paretic
KK4 = [27.25/26.91, 26.91/26.91, NaN, NaN, NaN,  NaN,   NaN,  24.74/26.91,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN]; %Sousa 2009 Paretic
KK4_lm = fitlm(bws(2:8),KK4(2:8));
KK4 = [fillmissing(KK4(1,:),'linear','Endvalues','none')];

KK1M = mean(KK1,'omitnan');
KK1S = std(KK1,'omitnan');
KK2M = mean(KK2,'omitnan');
KK2S = std(KK2,'omitnan');
KK3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KK4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KKM = [KK1M;KK2M;KK3;KK4]';
KKS = [KK1S;KK2S;KK3S;KK4S]';

figure 
superbar(bws,KKM, 'E', KKS,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 1.5])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Knee angle - ROM','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
KK1M_est = -0.0020.*bws(2:17) + 1.0141;
plot(bws(2:17),KK1M_est,'r--','linewidth',2) 
KK2M_est = -0.0033.*bws(2:10) + 1.0060;
plot(bws(2:10),KK2M_est,'b--','linewidth',2)
KK3_est = -0.0013.*bws(2:8) + 1;
plot(bws(2:8),KK3_est,'g--','linewidth',2)
KK4_est = -0.0027.*bws(2:8) + 1;
plot(bws(2:8),KK4_est,'m--','linewidth',2)

%% Ankle Joint Kinematics
%treadmill, healthy
AK1 = [ NaN, 1, NaN, NaN, NaN,  NaN,   0.9437,  NaN,  NaN,  NaN, NaN, 0.8303,  NaN, NaN,  NaN, NaN, 0.8508, NaN; %Ferris 2001
        NaN, 21.3/21.3, NaN, 22.1/21.3, NaN,  NaN,   NaN,  23.7/21.3,  NaN,  NaN, NaN,  23.3/21.3,  NaN, NaN,  NaN, 19.4/21.3, NaN, NaN; %Threlkeld 2003 
        NaN, 15.6735/15.6735 , NaN, NaN, NaN, NaN, 16.0729/15.6735, NaN,  NaN,  NaN, NaN,  14.3304/15.6735 ,  NaN, NaN,  NaN,  NaN, 12.7252/15.6735 , NaN ; %Van Hedel 2006  2km/h
        NaN, 30.7/30.7, NaN, NaN, NaN,  32.3/30.7,   NaN,  NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN]; %Franz 2007 

AK1L = AK1(:,2:17);
bws1 = repmat(bws(2:17),4,1);
AK1_lm = fitlm(bws1(:),AK1L(:));

AK1 = [fillmissing(AK1(1,:),'linear','Endvalues','none');
        fillmissing(AK1(2,:),'linear','Endvalues','none');
        fillmissing(AK1(3,:),'linear','Endvalues','none');
        fillmissing(AK1(4,:),'linear','Endvalues','none')];

%overground, healthy
AK2 = [36.24/31.34, 31.34/31.34, NaN, 27.34/31.34, NaN,  27.19/31.34,   NaN,  25.11/31.34,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN; %Patino 2007
        29/28, 28/28, NaN, NaN, 29.4/28,  NaN,   NaN,  26.8/28,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN; %Fischer 2014
        NaN, 21.78/21.78, NaN, 25.24/21.78, NaN, 22.08/21.78,   NaN,  23.66/21.78,  NaN,  22.64/21.78, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; %Mun 2016

AK2L = AK2(:,2:10);
bws2 = repmat(bws(2:10),3,1);
AK2_lm = fitlm(bws2(:),AK2L(:));

AK2 = [fillmissing(AK2(1,:),'linear','Endvalues','none');
        fillmissing(AK2(2,:),'linear','Endvalues','none');
        fillmissing(AK2(3,:),'linear','Endvalues','none')];

%overground, NI - nonparetic
AK3 = [ 26.22/25.73, 25.73/25.73,NaN, NaN, NaN,  NaN,   NaN,  25.83/25.73,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN]; %Sousa 2009 NonParetic
AK3_lm = fitlm(bws(2:8),AK3(2:8));
AK3 = [fillmissing(AK3(1,:),'linear','Endvalues','none')];
%overground, NI - paretic
AK4 = [18.23/17.90, 17.90/17.90, NaN, NaN, NaN,  NaN,   NaN,  17.40/17.90,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN]; %Sousa 2009 Paretic
AK4_lm = fitlm(bws(2:8),AK4(2:8));
AK4 = [fillmissing(AK4(1,:),'linear','Endvalues','none')];

AK1M = mean(AK1,'omitnan');
AK1S = std(AK1,'omitnan');
AK2M = mean(AK2,'omitnan');
AK2S = std(AK2,'omitnan');
AK3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AK4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AKM = [AK1M;AK2M;AK3;AK4]';
AKS = [AK1S;AK2S;AK3S;AK4S]';

figure 
superbar(bws,AKM, 'E', AKS,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 1.5])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Ankle angle - ROM','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
AK1M_est = -0.0020.*bws(2:17) + 1.0374;
plot(bws(2:17),AK1M_est,'r--','linewidth',2) 
AK2M_est = -8.7638e-04.*bws(2:10) + 1.0022;
plot(bws(2:10),AK2M_est,'b--','linewidth',2)
AK3_est = 0.000129550459904148.*bws(2:8) + 1;
plot(bws(2:8),AK3_est,'g--','linewidth',2)
AK4_est = -0.000931098696461802.*bws(2:8) + 1;
plot(bws(2:8),AK4_est,'m--','linewidth',2)

%% Hip extension Moment
HME1 = [ NaN, 1, NaN, NaN, NaN, 0.8806,  NaN, NaN, NaN, 0.7143,  NaN, NaN, NaN, 0.5325,  NaN, NaN, NaN, NaN]; %Goldberg 2013
HME1_lm = fitlm(bws(2:14),HME1(2:14));
HME1 = [fillmissing(HME1(1,:),'linear','Endvalues','none')];

HME2 = [6.2/4.76, 4.76/4.76, NaN, NaN, 4.71/4.76,  NaN,   NaN,  4.72/4.76,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; % Fischer 2014 - Extension
HME2_lm = fitlm(bws(2:8),HME2(2:8));
HME2 = [fillmissing(HME2(1,:),'linear','Endvalues','none')];
                
HME3 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HME4 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;

HME1S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HME2S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HME3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HME4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HMEM = [HME1;HME2;HME3;HME4]';
HMES = [HME1S;HME2S;HME3S;HME4S]';



figure 
superbar(bws,HMEM, 'E', HMES,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 1.5])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Hip Extension Moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
HME1M_est = -0.0078.*bws(2:14) + 1.0172;
plot(bws(2:14),HME1M_est,'r--','linewidth',2) 
HME2M_est = -0.0003.*bws(2:8) + 0.9979;
plot(bws(2:8),HME2M_est,'b--','linewidth',2)         
%% Hip flexion moment
HMF1 = [NaN, -1, NaN, NaN, NaN, -0.9141,  NaN, NaN, NaN, -0.6782,  NaN, NaN, NaN, -0.4884,  NaN, NaN, NaN, NaN]; %Goldberg 2013
HMF1_lm = fitlm(bws(2:14),HMF1(2:14));
HMF1 = [fillmissing(HMF1(1,:),'linear','Endvalues','none')];
HMF2 = [-5.87/5.14, -5.14/5.14, NaN, NaN, -4.05/5.14,  NaN,   NaN,  -2.93/5.14,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; %Fischer 2014 - Flexion
HMF2_lm = fitlm(bws(2:8),HMF2(2:8));
HMF2 = [fillmissing(HMF2(1,:),'linear','Endvalues','none')];        
HMF3 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HMF4 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;

HMF1S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HMF2S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HMF3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
HMF4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;

HMFM = [HMF1;HMF2;HMF3;HMF4]';
HMFS = [HMF1S;HMF2S;HMF3S;HMF4S]';

figure 
superbar(bws,HMFM, 'E', HMFS,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 -1.5 0])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Hip Flexion Moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
HMF1M_est = 0.0089.*bws(2:14) - 1.0358;
plot(bws(2:14),HMF1M_est,'r--','linewidth',2) 
HMF2M_est = 0.0143.*bws(2:8) - 1.0010;
plot(bws(2:8),HMF2M_est,'b--','linewidth',2) 
%% Knee extension Moment
KME1 = [ NaN, 1, NaN, NaN, NaN, 0.9394,  NaN, NaN, NaN, 0.8067,  NaN, NaN, NaN, 0.7898,  NaN, NaN, NaN, NaN]; %Goldberg 2013
KME1_lm = fitlm(bws(2:14),KME1(2:14));
KME1 = [fillmissing(KME1(1,:),'linear','Endvalues','none')]; 
KME2 = [2.5/2.36, 2.36/2.36, NaN, NaN, 2.1/2.36,  NaN,   NaN,  1.51/2.36,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; % Fischer 2014 - Extension
KME2_lm = fitlm(bws(2:8),KME2(2:8));
KME2 = [fillmissing(KME2(1,:),'linear','Endvalues','none')];
KME3 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KME4 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;


KME1S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KME2S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KME3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KME4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KMEM = [KME1;KME2;KME3;KME4]';
KMES = [KME1S;KME2S;KME3S;KME4S]';

figure 
superbar(bws,KMEM, 'E', KMES,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 1.5])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Knee Extension Moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
KME1M_est = -0.0038.*bws(2:14) + 0.9985;
plot(bws(2:14),KME1M_est,'r--','linewidth',2) 
KME2M_est = -0.012.*bws(2:8) + 1.0233;
plot(bws(2:8),KME2M_est,'b--','linewidth',2) 
%% Knee flexion moment        
KMF1 = [NaN, -1, NaN, NaN, NaN, -0.745,  NaN, NaN, NaN, -0.5100,  NaN, NaN, NaN, -0.1434,  NaN, NaN, NaN, NaN]; %Goldberg 2013
KMF1_lm = fitlm(bws(2:14),KMF1(2:14));
KMF1 = [fillmissing(KMF1(1,:),'linear','Endvalues','none')];
KMF2 = [-1.79/0.83, -0.83/0.83, NaN, NaN, -0.69/0.83,  NaN,   NaN,  -0.8/0.83,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; %Fischer 2014 - Flexion 
KMF2_lm = fitlm(bws(2:8),KMF2(2:8));
KMF2 = [fillmissing(KMF2(1,:),'linear','Endvalues','none')];
KMF3 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KMF4 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;

KMF1S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KMF2S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KMF3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KMF4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
KMFM = [KMF1;KMF2;KMF3;KMF4]';
KMFS = [KMF1S;KMF2S;KMF3S;KMF4S]';

figure 
superbar(bws,KMFM, 'E', KMFS,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
%xlim([-10 80])
axis([-10 80 -2.5 0])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Knee Flexion Moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
KMF1M_est = 0.0140.*bws(2:14) - 1.0203;
plot(bws(2:14),KMF1M_est,'r--','linewidth',2) 
KMF2M_est = 0.0012.*bws(2:8) - 0.9498;
plot(bws(2:8),KMF2M_est,'b--','linewidth',2)    
%% Ankle PF Moment
AME1 = [ NaN, 1, NaN, NaN, NaN, 0.8365, NaN, NaN, NaN,0.7104, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN; %Lewek 2010
         NaN, 1, NaN, NaN, NaN, 0.8451,  NaN, NaN, NaN, 0.7058,  NaN, NaN, NaN, 0.5177,  NaN, NaN, NaN, NaN]; %Goldberg 2013

AME1L = AME1(:,2:14);
bws1 = repmat(bws(2:14),2,1);
AME1_lm = fitlm(bws1(:),AME1L(:));

AME1 = [fillmissing(AME1(1,:),'linear','Endvalues','none');
        fillmissing(AME1(2,:),'linear','Endvalues','none')]; 

AME2 = [ 8.59/7.38, 7.38/7.38, NaN, NaN, 5.71/7.38,  NaN,   NaN,  4.62/7.38,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN, NaN, NaN]; % Fischer 2014 - Extension
AME2_lm = fitlm(bws(2:8),AME2(2:8));
AME2 = [fillmissing(AME2(1,:),'linear','Endvalues','none')]; 
AME3 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AME4 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;

AME1M = mean(AME1,'omitnan');
AME1S = std(AME1,'omitnan') ;
AME2S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AME3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AME4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AMEM = [AME1M;AME2;AME3;AME4]';
AMES = [AME1S;AME2S;AME3S;AME4S]';

figure 
superbar(bws,AMEM, 'E', AMES,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 2])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Ankle PF Moment','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
AME1M_est = -0.0078.*bws(2:14) + 1.0017;
plot(bws(2:14),AME1M_est,'r--','linewidth',2) 
AME2M_est = -0.0125.*bws(2:8) + 0.9869;
plot(bws(2:8),AME2M_est,'b--','linewidth',2)    
%% Ankle propulsive Impulse
%treadmill, healthy
AI1 = [ NaN, 1, NaN, NaN, NaN, 0.7815, NaN, NaN, NaN,0.6516, NaN, NaN, NaN, NaN, NaN, NaN, NaN, NaN ; %Lewek 2010  
        NaN, 1, NaN, NaN, NaN, NaN, 15.3/17.9, NaN, NaN,NaN, NaN, 11.3/17.9, NaN, NaN, NaN, NaN, NaN, NaN]; %McGowan2008        

AI1L = AI1(:,2:12);
bws1 = repmat(bws(2:12),2,1);
AI1_lm = fitlm(bws1(:),AI1L(:));

AI1 = [fillmissing(AI1(1,:),'linear','Endvalues','none');
        fillmissing(AI1(2,:),'linear','Endvalues','none')];

%overground, healthy
AI2 = [  NaN, 1, NaN, NaN, 0.7531,  NaN,   NaN,  0.6138,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN; %Barela 2014
         1.1501, 1, NaN, NaN, 0.7249,  NaN,   NaN,  0.6327,  NaN,  NaN, NaN,  NaN,  NaN, NaN,  NaN,  NaN , NaN, NaN]; %Fischer 2014

AI2L = AI2(:,2:8);
bws2 = repmat(bws(2:8),2,1);
AI2_lm = fitlm(bws2(:),AI2L(:));

AI2 = [fillmissing(AI2(1,:),'linear','Endvalues','none');
        fillmissing(AI2(2,:),'linear','Endvalues','none')];

AI3 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AI4 = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;

AI1M = mean(AI1,'omitnan');
AI1S = std(AI1,'omitnan');
AI2M = mean(AI2,'omitnan');
AI2S = std(AI2,'omitnan');
AI3S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AI4S = [ 0, 0, 0, 0, 0,  0,   0,  0,  0,  0, 0,  0,  0, 0,  0,  0, 0, 0] ;
AIM = [AI1M;AI2M;AI3;AI4]';
AIS = [AI1S;AI2S;AI3S;AI4S]';


figure 
superbar(bws,AIM, 'E', AIS,'BarFaceColor', permute(Colour, [4 1 2 3]));
grid on
grid minor
axis([-10 80 0 1.5])
xticks([-10 0 10 20 30 40 50 60 70 80])
xticklabels({'No BWS', '0', '10', '20', '30', '40', '50', '60', '70', '80'})
set(gca,'fontsize',36)
ylabel('Ankle Propulsive Impulse','FontSize',36,'FontWeight','bold')
xlabel('Percentage Body weight unloading (BWU)','FontSize',36,'FontWeight','bold')
hold on
AI1M_est = -0.0077.*bws(2:12) + 0.9929;
plot(bws(2:12),AI1M_est,'r--','linewidth',2) 
AI2M_est = -0.0126.*bws(2:8) + 0.9758;
plot(bws(2:8),AI2M_est,'b--','linewidth',2)